@@ -1,5 +1,5 @@
-from . import __app__
-from .enums import FormatTypeEnum, ProjectTypeEnum, VersionTypeEnum
+from badabump import __app__
+from badabump.enums import FormatTypeEnum, ProjectTypeEnum, VersionTypeEnum
 
 
 CHANGELOG_UPPER = "CHANGELOG"
@@ -8,6 +8,7 @@ CHANGELOG_LOWER = CHANGELOG_UPPER.lower()
 DEFAULT_CHANGELOG_FILE_INCLUDE_DATE = True
 DEFAULT_CHANGELOG_FORMAT_TYPE_FILE = FormatTypeEnum.markdown
 DEFAULT_CHANGELOG_FORMAT_TYPE_GIT = FormatTypeEnum.markdown
+DEFAULT_CHANGELOG_IGNORE_FOOTER_URLS = True
 DEFAULT_PROJECT_TYPE = ProjectTypeEnum.python
 DEFAULT_TAG_FORMAT = "v{version}"
 DEFAULT_TAG_SUBJECT_FORMAT = "{version} Release"
